var group__analysis =
[
    [ "mi_heap_area_t", "group__analysis.html#structmi__heap__area__t", [
      [ "block_size", "group__analysis.html#a332a6c14d736a99699d5453a1cb04b41", null ],
      [ "blocks", "group__analysis.html#ae0085e6e1cf059a4eb7767e30e9991b8", null ],
      [ "committed", "group__analysis.html#ab47526df656d8837ec3e97f11b83f835", null ],
      [ "full_block_size", "group__analysis.html#ab53664e31d7fe2564f8d42041ef75cb3", null ],
      [ "heap_tag", "group__analysis.html#a2b7a0c92ece8daf46b558efc990ebdc1", null ],
      [ "reserved", "group__analysis.html#ae848a3e6840414891035423948ca0383", null ],
      [ "used", "group__analysis.html#ab820302c5cd0df133eb8e51650a008b4", null ]
    ] ],
    [ "mi_block_visit_fun", "group__analysis.html#ga8255dc9371e6b299d9802a610c4e34ec", null ],
    [ "mi_abandoned_visit_blocks", "group__analysis.html#ga6a4865a887b2ec5247854af61562503c", null ],
    [ "mi_heap_visit_blocks", "group__analysis.html#gae69fcff3324f8e419af850e34cf54c46", null ]
];